#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var yargs_1 = __importDefault(require("yargs"));
var fs_1 = __importDefault(require("fs"));
var flagOptions_1 = require("./flagOptions");
var index_1 = require("../src/index");
var utils_1 = require("./utils");
var argv = (0, yargs_1.default)(process.argv.slice(2))
    .usage('Usage: gltf-optimizer -i inputPath -o outputPath')
    .example('gltf-optimizer', '-i model.glb')
    .example('gltf-optimizer', '-i model.glb -o ./output')
    .help('h')
    .alias('h', 'help')
    .options(flagOptions_1.flagOptions)
    .parseSync();
var glb = fs_1.default.readFileSync(argv.input);
void index_1.optimizer.node(glb, {
    emissiveStrength: argv.emissiveStrength,
    transform: {
        draco: {
            method: argv.draco.method
        },
        weld: {
            tolerance: argv.weld.tolerance
        },
        simplify: {
            enabled: argv.simplify.enabled,
            ratio: argv.simplify.ratio,
            error: argv.simplify.error
        },
        texture: {
            resize: {
                resolution: argv.texture.resize.resolution,
                filter: argv.texture.resize.filter
            }
        }
    }
})
    .then(function (result) {
    var outputDir = (0, utils_1.outputDirectory)(argv);
    if (!fs_1.default.existsSync(outputDir)) {
        fs_1.default.mkdirSync(outputDir);
    }
    fs_1.default.writeFileSync("".concat(outputDir, "/compressed.glb"), result);
});
